@@ -474,7 +474,8 @@ estimateSizeFactors.DESeqDataSet <- function(object, type=c("ratio","poscounts",
 #' @param geoMeans by default this is not provided and the
 #' geometric means of the counts are calculated within the function.
 #' A vector of geometric means from another count matrix can be provided
-#' for a "frozen" size factor calculation
+#' for a "frozen" size factor calculation. The size factors will be 
+#' scaled to have a geometric mean of 1 when supplying \code{geoMeans}.
 #' @param controlGenes optional, numeric or logical index vector specifying those genes to
 #' use for size factor estimation (e.g. housekeeping or spike-in genes)
 #' @param normMatrix optional, a matrix of normalization factors which do not yet
@@ -521,10 +522,11 @@ estimateSizeFactors.DESeqDataSet <- function(object, type=c("ratio","poscounts",
 setMethod("estimateSizeFactors", signature(object="DESeqDataSet"),
           estimateSizeFactors.DESeqDataSet)
 
-estimateDispersions.DESeqDataSet <- function(object, fitType=c("parametric","local","mean"),
+estimateDispersions.DESeqDataSet <- function(object, fitType=c("parametric","local","mean", "glmGamPoi"),
                                              maxit=100, useCR=TRUE,
                                              weightThreshold=1e-2,
-                                             quiet=FALSE, modelMatrix=NULL, minmu=0.5) {
+                                             quiet=FALSE, modelMatrix=NULL,
+                                             minmu=if (fitType=="glmGamPoi") 1e-6 else 0.5) {
   # Temporary hack for backward compatibility with "old" DESeqDataSet
   # objects. Remove once all serialized DESeqDataSet objects around have
   # been updated.
@@ -552,7 +554,16 @@ this column could have come in during colData import and should be removed.")
     mcols(object) <- mcols(object)[,!(mcols(mcols(object))$type %in% c("intermediate","results")),drop=FALSE]
   }
   stopifnot(length(maxit)==1)
-  fitType <- match.arg(fitType, choices=c("parametric","local","mean"))
+  fitType <- match.arg(fitType, choices=c("parametric","local","mean", "glmGamPoi"))
+  dispersionEstimator <- if (fitType == "glmGamPoi") {
+    if (!requireNamespace("glmGamPoi", quietly=TRUE)) {
+      stop("type='glmGamPoi' requires installing the Bioconductor package 'glmGamPoi'")
+    }
+    "glmGamPoi"
+  } else {
+    "DESeq2"
+  }
+  
   
   checkForExperimentalReplicates(object, modelMatrix)
   
@@ -563,10 +574,11 @@ this column could have come in during colData import and should be removed.")
                                        weightThreshold=weightThreshold,
                                        quiet=quiet,
                                        modelMatrix=modelMatrix,
-                                       minmu=minmu)
+                                       minmu=minmu,
+                                       type = dispersionEstimator)
   if (!quiet) message("mean-dispersion relationship")
   object <- estimateDispersionsFit(object,
-                                   fitType=fitType,
+                                   fitType= fitType,
                                    quiet=quiet)
   if (!quiet) message("final dispersion estimates")
   object <- estimateDispersionsMAP(object,
@@ -574,7 +586,8 @@ this column could have come in during colData import and should be removed.")
                                    useCR=useCR,
                                    weightThreshold=weightThreshold,
                                    quiet=quiet,
-                                   modelMatrix=modelMatrix)
+                                   modelMatrix=modelMatrix,
+                                   type = dispersionEstimator)
   
   return(object)
 }
@@ -636,6 +649,13 @@ checkForExperimentalReplicates <- function(object, modelMatrix) {
 #'
 #' In DESeq2, the dispersion estimation procedure described above replaces the
 #' different methods of dispersion from the previous version of the DESeq package.
+#' 
+#' Since version 1.29, DESeq2 can call the glmGamPoi package, which can speed up the inference
+#' and is optimized for fitting many samles with very small counts (for example single cell 
+#' RNA-seq data). To call functions from the glmGamPoi package, make sure that it is installed
+#' and set \code{fitType = "glmGamPoi"}. In addition, to the gene estimates, the trend and the MAP,
+#' the glmGamPoi package calculates the corresponding quasi-likelihood estimates. Those can be
+#' used with the \code{nbinomLRT()} test to get more precise p-value estimates.
 #'
 #' The lower-level functions called by \code{estimateDispersions} are:
 #' \code{\link{estimateDispersionsGeneEst}},
@@ -647,7 +667,7 @@ checkForExperimentalReplicates <- function(object, modelMatrix) {
 #' @rdname estimateDispersions
 #' @aliases estimateDispersions estimateDispersions,DESeqDataSet-method
 #' @param object a DESeqDataSet
-#' @param fitType either "parametric", "local", or "mean"
+#' @param fitType either "parametric", "local", "mean", or "glmGamPoi"
 #' for the type of fitting of dispersions to the mean intensity.
 #' \itemize{
 #'   \item parametric - fit a dispersion-mean relation of the form:
@@ -660,6 +680,9 @@ checkForExperimentalReplicates <- function(object, modelMatrix) {
 #'     are input and output for \code{\link{dispersionFunction}}). The points
 #'     are weighted by normalized mean count in the local regression.
 #'   \item mean - use the mean of gene-wise dispersion estimates.
+#'   \item glmGamPoi - use the glmGamPoi package to fit the gene-wise dispersion, its trend
+#'     and calculate the MAP based on the quasi-likelihood framework. The trend is 
+#'     calculated using a local median regression.
 #' }
 #' @param maxit control parameter: maximum number of iterations to allow for convergence
 #' @param useCR whether to use Cox-Reid correction - see McCarthy et al (2012)
@@ -683,6 +706,8 @@ checkForExperimentalReplicates <- function(object, modelMatrix) {
 #'   \item Wu, H., Wang, C. & Wu, Z. A new shrinkage estimator for dispersion improves differential
 #' expression detection in RNA-seq data. Biostatistics (2012).
 #' \url{http://dx.doi.org/10.1093/biostatistics/kxs033}
+#'   \item Ahlmann-Eltze, C., Huber, W. glmGamPoi: Fitting Gamma-Poisson Generalized Linear Models on Single Cell Count Data. bioRxiv (2020).
+#' \url{https://doi.org/10.1101/2020.08.13.249623}
 #' }
 #'
 #' @examples
