@@ -175,11 +175,12 @@
 #' @param test this is automatically detected internally if not provided.
 #' the one exception is after \code{nbinomLRT} has been run, \code{test="Wald"}
 #' will generate Wald statistics and Wald test p-values.
-#' @param addMLE if \code{betaPrior=TRUE} was used,
-#' whether the "unshrunken" maximum likelihood estimates (MLE)
+#' @param addMLE if \code{betaPrior=TRUE} was used (non-default),
+#' this logical argument specifies if the "unshrunken" maximum likelihood estimates (MLE)
 #' of log2 fold change should be added as a column to the results table (default is FALSE).
-#' This argument is preserved for backward compatability, as now the
-#' recommended pipeline is to generate shrunken MAP estimates using \code{\link{lfcShrink}}.
+#' This argument is preserved for backward compatability, as now \code{betaPrior=TRUE}
+#' by default and the recommended pipeline is
+#' to generate shrunken MAP estimates using \code{\link{lfcShrink}}.
 #' This argument functionality is only implemented for \code{contrast}
 #' specified as three element character vectors.
 #' @param tidy whether to output the results table with rownames as a first column 'row'.
@@ -233,8 +234,6 @@
 #' dds <- DESeq(dds) 
 #' resultsNames(dds)
 #'
-#' # Note: design with interactions terms by default have betaPrior=FALSE
-#'
 #' # the condition effect for genotype I (the main effect)
 #' results(dds, contrast=c("condition","B","A"))
 #'
@@ -775,6 +774,9 @@ cleanContrast <- function(object, contrast, expanded=FALSE, listValues, test, us
     if (!contrastFactor %in% names(colData(object))) {
       stop(paste(contrastFactor,"should be the name of a factor in the colData of the DESeqDataSet"))
     }
+    if (!is(colData(object)[[contrastFactor]], "factor")) {
+      stop(paste(contrastFactor,"is not a factor, see ?results"))
+    }
     contrastNumLevel <- contrast[2]
     contrastDenomLevel <- contrast[3]
     contrastBaseLevel <- levels(colData(object)[,contrastFactor])[1]
