@@ -1,10 +1,10 @@
-## ----setup, echo=FALSE, results="hide"-----------------------------------
+## ----setup, echo=FALSE, results="hide"----------------------------------------
 knitr::opts_chunk$set(tidy = FALSE,
                       cache = FALSE,
                       dev = "png",
                       message = FALSE, error = FALSE, warning = TRUE)
 
-## ----quickStart, eval=FALSE----------------------------------------------
+## ----quickStart, eval=FALSE---------------------------------------------------
 #  dds <- DESeqDataSetFromMatrix(countData = cts,
 #                                colData = coldata,
 #                                design= ~ batch + condition)
@@ -14,7 +14,7 @@ knitr::opts_chunk$set(tidy = FALSE,
 #  # or to shrink log fold changes association with condition:
 #  res <- lfcShrink(dds, coef="condition_trt_vs_untrt", type="apeglm")
 
-## ----txiSetup------------------------------------------------------------
+## ----txiSetup-----------------------------------------------------------------
 library("tximport")
 library("readr")
 library("tximportData")
@@ -24,36 +24,36 @@ samples$condition <- factor(rep(c("A","B"),each=3))
 rownames(samples) <- samples$run
 samples[,c("pop","center","run","condition")]
 
-## ----txiFiles------------------------------------------------------------
+## ----txiFiles-----------------------------------------------------------------
 files <- file.path(dir,"salmon", samples$run, "quant.sf.gz")
 names(files) <- samples$run
 tx2gene <- read_csv(file.path(dir, "tx2gene.gencode.v27.csv"))
 
-## ----tximport, results="hide"--------------------------------------------
+## ----tximport, results="hide"-------------------------------------------------
 txi <- tximport(files, type="salmon", tx2gene=tx2gene)
 
-## ----txi2dds, results="hide"---------------------------------------------
+## ----txi2dds, results="hide"--------------------------------------------------
 library("DESeq2")
 ddsTxi <- DESeqDataSetFromTximport(txi,
                                    colData = samples,
                                    design = ~ condition)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 coldata <- samples
 coldata$files <- files
 coldata$names <- coldata$run
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 library("tximeta")
 se <- tximeta(coldata, skipMeta=TRUE)
 ddsTxi2 <- DESeqDataSet(se, design = ~condition)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  library("tximeta")
 #  se <- tximeta(coldata)
 #  ddsTxi <- DESeqDataSet(se, design = ~ condition)
 
-## ----loadPasilla---------------------------------------------------------
+## ----loadPasilla--------------------------------------------------------------
 library("pasilla")
 pasCts <- system.file("extdata",
                       "pasilla_gene_counts.tsv",
@@ -64,140 +64,144 @@ pasAnno <- system.file("extdata",
 cts <- as.matrix(read.csv(pasCts,sep="\t",row.names="gene_id"))
 coldata <- read.csv(pasAnno, row.names=1)
 coldata <- coldata[,c("condition","type")]
+coldata$condition <- factor(coldata$condition)
+coldata$type <- factor(coldata$type)
 
-## ----showPasilla---------------------------------------------------------
+## ----showPasilla--------------------------------------------------------------
 head(cts,2)
 coldata
 
-## ----reorderPasila-------------------------------------------------------
+## ----reorderPasila------------------------------------------------------------
 rownames(coldata) <- sub("fb", "", rownames(coldata))
 all(rownames(coldata) %in% colnames(cts))
 all(rownames(coldata) == colnames(cts))
 cts <- cts[, rownames(coldata)]
 all(rownames(coldata) == colnames(cts))
 
-## ----matrixInput---------------------------------------------------------
+## ----matrixInput--------------------------------------------------------------
 library("DESeq2")
 dds <- DESeqDataSetFromMatrix(countData = cts,
                               colData = coldata,
                               design = ~ condition)
 dds
 
-## ----addFeatureData------------------------------------------------------
+## ----addFeatureData-----------------------------------------------------------
 featureData <- data.frame(gene=rownames(cts))
 mcols(dds) <- DataFrame(mcols(dds), featureData)
 mcols(dds)
 
-## ----htseqDirI, eval=FALSE-----------------------------------------------
+## ----htseqDirI, eval=FALSE----------------------------------------------------
 #  directory <- "/path/to/your/files/"
 
-## ----htseqDirII----------------------------------------------------------
+## ----htseqDirII---------------------------------------------------------------
 directory <- system.file("extdata", package="pasilla",
                          mustWork=TRUE)
 
-## ----htseqInput----------------------------------------------------------
+## ----htseqInput---------------------------------------------------------------
 sampleFiles <- grep("treated",list.files(directory),value=TRUE)
 sampleCondition <- sub("(.*treated).*","\\1",sampleFiles)
 sampleTable <- data.frame(sampleName = sampleFiles,
                           fileName = sampleFiles,
                           condition = sampleCondition)
+sampleTable$condition <- factor(sampleTable$condition)
 
-## ----hsteqDds------------------------------------------------------------
+## ----hsteqDds-----------------------------------------------------------------
 library("DESeq2")
 ddsHTSeq <- DESeqDataSetFromHTSeqCount(sampleTable = sampleTable,
                                        directory = directory,
                                        design= ~ condition)
 ddsHTSeq
 
-## ----loadSumExp----------------------------------------------------------
+## ----loadSumExp---------------------------------------------------------------
 library("airway")
 data("airway")
 se <- airway
 
-## ----sumExpInput---------------------------------------------------------
+## ----sumExpInput--------------------------------------------------------------
 library("DESeq2")
 ddsSE <- DESeqDataSet(se, design = ~ cell + dex)
 ddsSE
 
-## ----prefilter-----------------------------------------------------------
+## ----prefilter----------------------------------------------------------------
 keep <- rowSums(counts(dds)) >= 10
 dds <- dds[keep,]
 
-## ----factorlvl-----------------------------------------------------------
+## ----factorlvl----------------------------------------------------------------
 dds$condition <- factor(dds$condition, levels = c("untreated","treated"))
 
-## ----relevel-------------------------------------------------------------
+## ----relevel------------------------------------------------------------------
 dds$condition <- relevel(dds$condition, ref = "untreated")
 
-## ----droplevels----------------------------------------------------------
+## ----droplevels---------------------------------------------------------------
 dds$condition <- droplevels(dds$condition)
 
-## ----deseq---------------------------------------------------------------
+## ----deseq--------------------------------------------------------------------
 dds <- DESeq(dds)
 res <- results(dds)
 res
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  res <- results(dds, name="condition_treated_vs_untreated")
 #  res <- results(dds, contrast=c("condition","treated","untreated"))
 
-## ----lfcShrink-----------------------------------------------------------
+## ----lfcShrink----------------------------------------------------------------
 resultsNames(dds)
 resLFC <- lfcShrink(dds, coef="condition_treated_vs_untreated", type="apeglm")
 resLFC
 
-## ----parallel, eval=FALSE------------------------------------------------
+## ----parallel, eval=FALSE-----------------------------------------------------
 #  library("BiocParallel")
 #  register(MulticoreParam(4))
 
-## ----resOrder------------------------------------------------------------
+## ----resOrder-----------------------------------------------------------------
 resOrdered <- res[order(res$pvalue),]
 
-## ----sumRes--------------------------------------------------------------
+## ----sumRes-------------------------------------------------------------------
 summary(res)
 
-## ----sumRes01------------------------------------------------------------
+## ----sumRes01-----------------------------------------------------------------
 sum(res$padj < 0.1, na.rm=TRUE)
 
-## ----resAlpha05----------------------------------------------------------
+## ----resAlpha05---------------------------------------------------------------
 res05 <- results(dds, alpha=0.05)
 summary(res05)
 sum(res05$padj < 0.05, na.rm=TRUE)
 
-## ----IHW-----------------------------------------------------------------
-library("IHW")
-resIHW <- results(dds, filterFun=ihw)
-summary(resIHW)
-sum(resIHW$padj < 0.1, na.rm=TRUE)
-metadata(resIHW)$ihwResult
+## ----IHW, eval=FALSE----------------------------------------------------------
+#  # (unevaluated code chunk)
+#  library("IHW")
+#  resIHW <- results(dds, filterFun=ihw)
+#  summary(resIHW)
+#  sum(resIHW$padj < 0.1, na.rm=TRUE)
+#  metadata(resIHW)$ihwResult
 
-## ----MA------------------------------------------------------------------
+## ----MA-----------------------------------------------------------------------
 plotMA(res, ylim=c(-2,2))
 
-## ----shrunkMA------------------------------------------------------------
+## ----shrunkMA-----------------------------------------------------------------
 plotMA(resLFC, ylim=c(-2,2))
 
-## ----MAidentify, eval=FALSE----------------------------------------------
+## ----MAidentify, eval=FALSE---------------------------------------------------
 #  idx <- identify(res$baseMean, res$log2FoldChange)
 #  rownames(res)[idx]
 
-## ----warning=FALSE-------------------------------------------------------
+## ----warning=FALSE------------------------------------------------------------
 resultsNames(dds)
 # because we are interested in treated vs untreated, we set 'coef=2'
 resNorm <- lfcShrink(dds, coef=2, type="normal")
 resAsh <- lfcShrink(dds, coef=2, type="ashr")
 
-## ----fig.width=8, fig.height=3-------------------------------------------
+## ----fig.width=8, fig.height=3------------------------------------------------
 par(mfrow=c(1,3), mar=c(4,4,2,1))
 xlim <- c(1,1e5); ylim <- c(-3,3)
 plotMA(resLFC, xlim=xlim, ylim=ylim, main="apeglm")
 plotMA(resNorm, xlim=xlim, ylim=ylim, main="normal")
 plotMA(resAsh, xlim=xlim, ylim=ylim, main="ashr")
 
-## ----plotCounts----------------------------------------------------------
+## ----plotCounts---------------------------------------------------------------
 plotCounts(dds, gene=which.min(res$padj), intgroup="condition")
 
-## ----plotCountsAdv-------------------------------------------------------
+## ----plotCountsAdv------------------------------------------------------------
 d <- plotCounts(dds, gene=which.min(res$padj), intgroup="condition", 
                 returnData=TRUE)
 library("ggplot2")
@@ -205,47 +209,47 @@ ggplot(d, aes(x=condition, y=count)) +
   geom_point(position=position_jitter(w=0.1,h=0)) + 
   scale_y_log10(breaks=c(25,100,400))
 
-## ----metadata------------------------------------------------------------
+## ----metadata-----------------------------------------------------------------
 mcols(res)$description
 
-## ----export, eval=FALSE--------------------------------------------------
+## ----export, eval=FALSE-------------------------------------------------------
 #  write.csv(as.data.frame(resOrdered),
 #            file="condition_treated_results.csv")
 
-## ----subset--------------------------------------------------------------
+## ----subset-------------------------------------------------------------------
 resSig <- subset(resOrdered, padj < 0.1)
 resSig
 
-## ----multifactor---------------------------------------------------------
+## ----multifactor--------------------------------------------------------------
 colData(dds)
 
-## ----copyMultifactor-----------------------------------------------------
+## ----copyMultifactor----------------------------------------------------------
 ddsMF <- dds
 
-## ----fixLevels-----------------------------------------------------------
+## ----fixLevels----------------------------------------------------------------
 levels(ddsMF$type)
 levels(ddsMF$type) <- sub("-.*", "", levels(ddsMF$type))
 levels(ddsMF$type)
 
-## ----replaceDesign-------------------------------------------------------
+## ----replaceDesign------------------------------------------------------------
 design(ddsMF) <- formula(~ type + condition)
 ddsMF <- DESeq(ddsMF)
 
-## ----multiResults--------------------------------------------------------
+## ----multiResults-------------------------------------------------------------
 resMF <- results(ddsMF)
 head(resMF)
 
-## ----multiTypeResults----------------------------------------------------
+## ----multiTypeResults---------------------------------------------------------
 resMFType <- results(ddsMF,
                      contrast=c("type", "single", "paired"))
 head(resMFType)
 
-## ----rlogAndVST----------------------------------------------------------
+## ----rlogAndVST---------------------------------------------------------------
 vsd <- vst(dds, blind=FALSE)
 rld <- rlog(dds, blind=FALSE)
 head(assay(vsd), 3)
 
-## ----meansd--------------------------------------------------------------
+## ----meansd-------------------------------------------------------------------
 # this gives log2(n + 1)
 ntd <- normTransform(dds)
 library("vsn")
@@ -253,7 +257,7 @@ meanSdPlot(assay(ntd))
 meanSdPlot(assay(vsd))
 meanSdPlot(assay(rld))
 
-## ----heatmap-------------------------------------------------------------
+## ----heatmap------------------------------------------------------------------
 library("pheatmap")
 select <- order(rowMeans(counts(dds,normalized=TRUE)),
                 decreasing=TRUE)[1:20]
@@ -265,10 +269,10 @@ pheatmap(assay(vsd)[select,], cluster_rows=FALSE, show_rownames=FALSE,
 pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=FALSE,
          cluster_cols=FALSE, annotation_col=df)
 
-## ----sampleClust---------------------------------------------------------
+## ----sampleClust--------------------------------------------------------------
 sampleDists <- dist(t(assay(vsd)))
 
-## ----figHeatmapSamples, fig.height=4, fig.width=6------------------------
+## ----figHeatmapSamples, fig.height=4, fig.width=6-----------------------------
 library("RColorBrewer")
 sampleDistMatrix <- as.matrix(sampleDists)
 rownames(sampleDistMatrix) <- paste(vsd$condition, vsd$type, sep="-")
@@ -279,10 +283,10 @@ pheatmap(sampleDistMatrix,
          clustering_distance_cols=sampleDists,
          col=colors)
 
-## ----figPCA--------------------------------------------------------------
+## ----figPCA-------------------------------------------------------------------
 plotPCA(vsd, intgroup=c("condition", "type"))
 
-## ----figPCA2-------------------------------------------------------------
+## ----figPCA2------------------------------------------------------------------
 pcaData <- plotPCA(vsd, intgroup=c("condition", "type"), returnData=TRUE)
 percentVar <- round(100 * attr(pcaData, "percentVar"))
 ggplot(pcaData, aes(PC1, PC2, color=condition, shape=type)) +
@@ -291,22 +295,22 @@ ggplot(pcaData, aes(PC1, PC2, color=condition, shape=type)) +
   ylab(paste0("PC2: ",percentVar[2],"% variance")) + 
   coord_fixed()
 
-## ----WaldTest, eval=FALSE------------------------------------------------
+## ----WaldTest, eval=FALSE-----------------------------------------------------
 #  dds <- estimateSizeFactors(dds)
 #  dds <- estimateDispersions(dds)
 #  dds <- nbinomWaldTest(dds)
 
-## ----simpleContrast, eval=FALSE------------------------------------------
+## ----simpleContrast, eval=FALSE-----------------------------------------------
 #  results(dds, contrast=c("condition","C","B"))
 
-## ----combineFactors, eval=FALSE------------------------------------------
+## ----combineFactors, eval=FALSE-----------------------------------------------
 #  dds$group <- factor(paste0(dds$genotype, dds$condition))
 #  design(dds) <- ~ group
 #  dds <- DESeq(dds)
 #  resultsNames(dds)
 #  results(dds, contrast=c("group", "IB", "IA"))
 
-## ----interFig, echo=FALSE, results="hide", fig.height=3------------------
+## ----interFig, echo=FALSE, results="hide", fig.height=3-----------------------
 npg <- 20
 mu <- 2^c(8,10,9,11,10,12)
 cond <- rep(rep(c("A","B"),each=npg),3)
@@ -325,7 +329,7 @@ plotit <- function(d, title) {
 plotit(d, "Gene 1") + ylim(7,13)
 lm(log2c ~ cond + geno + geno:cond, data=d)
 
-## ----interFig2, echo=FALSE, results="hide", fig.height=3-----------------
+## ----interFig2, echo=FALSE, results="hide", fig.height=3----------------------
 mu[4] <- 2^12
 mu[6] <- 2^8
 counts <- rnbinom(6*npg, mu=rep(mu,each=npg), size=1/.01)
@@ -333,20 +337,20 @@ d2 <- data.frame(log2c=log2(counts + 1), cond, geno)
 plotit(d2, "Gene 2") + ylim(7,13)
 lm(log2c ~ cond + geno + geno:cond, data=d2)
 
-## ----simpleLRT, eval=FALSE-----------------------------------------------
+## ----simpleLRT, eval=FALSE----------------------------------------------------
 #  dds <- DESeq(dds, test="LRT", reduced=~1)
 #  res <- results(dds)
 
-## ----simpleLRT2, eval=FALSE----------------------------------------------
+## ----simpleLRT2, eval=FALSE---------------------------------------------------
 #  dds <- DESeq(dds, test="LRT", reduced=~batch)
 #  res <- results(dds)
 
-## ----apeThresh-----------------------------------------------------------
+## ----apeThresh----------------------------------------------------------------
 resApeT <- lfcShrink(dds, coef=2, type="apeglm", lfcThreshold=1)
 plotMA(resApeT, ylim=c(-3,3), cex=.8)
 abline(h=c(-1,1), col="dodgerblue", lwd=2)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 condition <- factor(rep(c("A","B","C"),each=2))
 model.matrix(~ condition)
 # to compare C vs B, make B the reference level,
@@ -354,7 +358,7 @@ model.matrix(~ condition)
 condition <- relevel(condition, "B")
 model.matrix(~ condition)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 grp <- factor(rep(1:3,each=4))
 cnd <- factor(rep(rep(c("A","B"),each=2),3))
 model.matrix(~ grp + cnd + grp:cnd)
@@ -364,7 +368,7 @@ model.matrix(~ grp + cnd + grp:cnd)
 grp <- relevel(grp, "2")
 model.matrix(~ grp + cnd + grp:cnd)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 grp <- factor(rep(1:2,each=4))
 ind <- factor(rep(rep(1:2,each=2),2))
 cnd <- factor(rep(c("A","B"),4))
@@ -374,14 +378,14 @@ model.matrix(~grp + grp:ind + grp:cnd)
 # and select the last coefficient
 model.matrix(~grp + cnd + grp:ind + grp:cnd)
 
-## ----boxplotCooks--------------------------------------------------------
+## ----boxplotCooks-------------------------------------------------------------
 par(mar=c(8,5,2,2))
 boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2)
 
-## ----dispFit-------------------------------------------------------------
+## ----dispFit------------------------------------------------------------------
 plotDispEsts(dds)
 
-## ----dispFitCustom-------------------------------------------------------
+## ----dispFitCustom------------------------------------------------------------
 ddsCustom <- dds
 useForMedian <- mcols(ddsCustom)$dispGeneEst > 1e-7
 medianDisp <- median(mcols(ddsCustom)$dispGeneEst[useForMedian],
@@ -389,7 +393,7 @@ medianDisp <- median(mcols(ddsCustom)$dispGeneEst[useForMedian],
 dispersionFunction(ddsCustom) <- function(mu) medianDisp
 ddsCustom <- estimateDispersionsMAP(ddsCustom)
 
-## ----filtByMean----------------------------------------------------------
+## ----filtByMean---------------------------------------------------------------
 metadata(res)$alpha
 metadata(res)$filterThreshold
 plot(metadata(res)$filterNumRej, 
@@ -398,12 +402,12 @@ plot(metadata(res)$filterNumRej,
 lines(metadata(res)$lo.fit, col="red")
 abline(v=metadata(res)$filterTheta)
 
-## ----noFilt--------------------------------------------------------------
+## ----noFilt-------------------------------------------------------------------
 resNoFilt <- results(dds, independentFiltering=FALSE)
 addmargins(table(filtering=(res$padj < .1),
                  noFiltering=(resNoFilt$padj < .1)))
 
-## ----lfcThresh-----------------------------------------------------------
+## ----lfcThresh----------------------------------------------------------------
 par(mfrow=c(2,2),mar=c(2,2,1,1))
 ylim <- c(-2.5,2.5)
 resGA <- results(dds, lfcThreshold=.5, altHypothesis="greaterAbs")
@@ -416,96 +420,96 @@ plotMA(resLA, ylim=ylim); drawLines()
 plotMA(resG, ylim=ylim); drawLines()
 plotMA(resL, ylim=ylim); drawLines()
 
-## ----mcols---------------------------------------------------------------
+## ----mcols--------------------------------------------------------------------
 mcols(dds,use.names=TRUE)[1:4,1:4]
 substr(names(mcols(dds)),1,10) 
 mcols(mcols(dds), use.names=TRUE)[1:4,]
 
-## ----muAndCooks----------------------------------------------------------
+## ----muAndCooks---------------------------------------------------------------
 head(assays(dds)[["mu"]])
 head(assays(dds)[["cooks"]])
 
-## ----dispersions---------------------------------------------------------
+## ----dispersions--------------------------------------------------------------
 head(dispersions(dds))
 head(mcols(dds)$dispersion)
 
-## ----sizefactors---------------------------------------------------------
+## ----sizefactors--------------------------------------------------------------
 sizeFactors(dds)
 
-## ----coef----------------------------------------------------------------
+## ----coef---------------------------------------------------------------------
 head(coef(dds))
 
-## ----betaPriorVar--------------------------------------------------------
+## ----betaPriorVar-------------------------------------------------------------
 attr(dds, "betaPriorVar")
 
-## ----priorInfo-----------------------------------------------------------
+## ----priorInfo----------------------------------------------------------------
 priorInfo(resLFC)
 priorInfo(resNorm)
 priorInfo(resAsh)
 
-## ----dispPriorVar--------------------------------------------------------
+## ----dispPriorVar-------------------------------------------------------------
 dispersionFunction(dds)
 attr(dispersionFunction(dds), "dispPriorVar")
 
-## ----versionNum----------------------------------------------------------
+## ----versionNum---------------------------------------------------------------
 metadata(dds)[["version"]]
 
-## ----normFactors, eval=FALSE---------------------------------------------
+## ----normFactors, eval=FALSE--------------------------------------------------
 #  normFactors <- normFactors / exp(rowMeans(log(normFactors)))
 #  normalizationFactors(dds) <- normFactors
 
-## ----offsetTransform, eval=FALSE-----------------------------------------
+## ----offsetTransform, eval=FALSE----------------------------------------------
 #  cqnOffset <- cqnObject$glm.offset
 #  cqnNormFactors <- exp(cqnOffset)
 #  EDASeqNormFactors <- exp(-1 * EDASeqOffset)
 
-## ----lineardep, echo=FALSE-----------------------------------------------
+## ----lineardep, echo=FALSE----------------------------------------------------
 DataFrame(batch=factor(c(1,1,2,2)), condition=factor(c("A","A","B","B")))
 
-## ----lineardep2, echo=FALSE----------------------------------------------
+## ----lineardep2, echo=FALSE---------------------------------------------------
 DataFrame(batch=factor(c(1,1,1,1,2,2)), condition=factor(c("A","A","B","B","C","C")))
 
-## ----lineardep3, echo=FALSE----------------------------------------------
+## ----lineardep3, echo=FALSE---------------------------------------------------
 DataFrame(batch=factor(c(1,1,1,2,2,2)), condition=factor(c("A","B","C","A","B","C")))
 
-## ----groupeffect---------------------------------------------------------
+## ----groupeffect--------------------------------------------------------------
 coldata <- DataFrame(grp=factor(rep(c("X","Y"),each=6)),
                        ind=factor(rep(1:6,each=2)),
                       cnd=factor(rep(c("A","B"),6)))
 coldata
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 as.data.frame(coldata)
 
-## ----groupeffect2--------------------------------------------------------
+## ----groupeffect2-------------------------------------------------------------
 coldata$ind.n <- factor(rep(rep(1:3,each=2),2))
 as.data.frame(coldata)
 
-## ----groupeffect3--------------------------------------------------------
+## ----groupeffect3-------------------------------------------------------------
 model.matrix(~ grp + grp:ind.n + grp:cnd, coldata)
 
-## ----groupeffect4, eval=FALSE--------------------------------------------
+## ----groupeffect4, eval=FALSE-------------------------------------------------
 #  results(dds, contrast=list("grpY.cndB","grpX.cndB"))
 
-## ----missingcombo--------------------------------------------------------
+## ----missingcombo-------------------------------------------------------------
 group <- factor(rep(1:3,each=6))
 condition <- factor(rep(rep(c("A","B","C"),each=2),3))
 d <- DataFrame(group, condition)[-c(17,18),]
 as.data.frame(d)
 
-## ----missingcombo2-------------------------------------------------------
+## ----missingcombo2------------------------------------------------------------
 m1 <- model.matrix(~ condition*group, d)
 colnames(m1)
 unname(m1)
 all.zero <- apply(m1, 2, function(x) all(x==0))
 all.zero
 
-## ----missingcombo3-------------------------------------------------------
+## ----missingcombo3------------------------------------------------------------
 idx <- which(all.zero)
 m1 <- m1[,-idx]
 unname(m1)
 
-## ----cooksPlot-----------------------------------------------------------
+## ----cooksPlot----------------------------------------------------------------
 W <- res$stat
 maxCooks <- apply(assays(dds)[["cooks"]],1,max)
 idx <- !is.na(W)
@@ -516,37 +520,37 @@ m <- ncol(dds)
 p <- 3
 abline(h=qf(.99, p, m - p))
 
-## ----indFilt-------------------------------------------------------------
+## ----indFilt------------------------------------------------------------------
 plot(res$baseMean+1, -log10(res$pvalue),
      log="x", xlab="mean of normalized counts",
      ylab=expression(-log[10](pvalue)),
      ylim=c(0,30),
      cex=.4, col=rgb(0,0,0,.3))
 
-## ----histindepfilt-------------------------------------------------------
+## ----histindepfilt------------------------------------------------------------
 use <- res$baseMean > metadata(res)$filterThreshold
 h1 <- hist(res$pvalue[!use], breaks=0:50/50, plot=FALSE)
 h2 <- hist(res$pvalue[use], breaks=0:50/50, plot=FALSE)
 colori <- c(`do not pass`="khaki", `pass`="powderblue")
 
-## ----fighistindepfilt----------------------------------------------------
+## ----fighistindepfilt---------------------------------------------------------
 barplot(height = rbind(h1$counts, h2$counts), beside = FALSE,
         col = colori, space = 0, main = "", ylab="frequency")
 text(x = c(0, length(h1$counts)), y = 0, label = paste(c(0,1)),
      adj = c(0.5,1.7), xpd=NA)
 legend("topright", fill=rev(colori), legend=rev(names(colori)))
 
-## ----vanillaDESeq, eval=FALSE--------------------------------------------
+## ----vanillaDESeq, eval=FALSE-------------------------------------------------
 #  dds <- DESeq(dds, minReplicatesForReplace=Inf)
 #  res <- results(dds, cooksCutoff=FALSE, independentFiltering=FALSE)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  mat <- assay(vsd)
 #  mat <- limma::removeBatchEffect(mat, vsd$batch)
 #  assay(vsd) <- mat
 #  plotPCA(vsd)
 
-## ----varGroup, echo=FALSE------------------------------------------------
+## ----varGroup, echo=FALSE-----------------------------------------------------
 set.seed(3)
 dds1 <- makeExampleDESeqDataSet(n=1000,m=12,betaSD=.3,dispMeanRel=function(x) 0.01)
 dds2 <- makeExampleDESeqDataSet(n=1000,m=12,
@@ -561,9 +565,9 @@ dds12 <- cbind(dds1, dds2)
 rld <- rlog(dds12, blind=FALSE, fitType="mean")
 plotPCA(rld)
 
-## ----convertNA, eval=FALSE-----------------------------------------------
+## ----convertNA, eval=FALSE----------------------------------------------------
 #  res$padj <- ifelse(is.na(res$padj), 1, res$padj)
 
-## ----sessionInfo---------------------------------------------------------
+## ----sessionInfo--------------------------------------------------------------
 sessionInfo()
 
